# coding: utf-8

"""
    ThingsBoard REST API

    For instructions how to authorize requests please visit <a href='http://thingsboard.io/docs/reference/rest-api/'>REST API documentation page</a>.  # noqa: E501

    OpenAPI spec version: 3.9.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from tb_rest_client.api_client import ApiClient


class BillingEndpointControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def check_tenant_can_update_plan_using_post(self, body, **kwargs):  # noqa: E501
        """checkTenantCanUpdatePlan  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.check_tenant_can_update_plan_using_post(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: canUpdatePlanRequest (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.check_tenant_can_update_plan_using_post_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.check_tenant_can_update_plan_using_post_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def check_tenant_can_update_plan_using_post_with_http_info(self, body, **kwargs):  # noqa: E501
        """checkTenantCanUpdatePlan  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.check_tenant_can_update_plan_using_post_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: canUpdatePlanRequest (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method check_tenant_can_update_plan_using_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `check_tenant_can_update_plan_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/billingEndpoint/tenantCanUpdatePlan', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def notify_tenant_plan_changed_using_post(self, body, **kwargs):  # noqa: E501
        """notifyTenantPlanChanged  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.notify_tenant_plan_changed_using_post(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: tenantPlanChangedRequest (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.notify_tenant_plan_changed_using_post_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.notify_tenant_plan_changed_using_post_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def notify_tenant_plan_changed_using_post_with_http_info(self, body, **kwargs):  # noqa: E501
        """notifyTenantPlanChanged  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.notify_tenant_plan_changed_using_post_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: tenantPlanChangedRequest (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method notify_tenant_plan_changed_using_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `notify_tenant_plan_changed_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/billingEndpoint/tenantPlanChanged', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def notify_tenant_state_changed_using_post(self, body, **kwargs):  # noqa: E501
        """notifyTenantStateChanged  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.notify_tenant_state_changed_using_post(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: tenantStateChangedRequest (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.notify_tenant_state_changed_using_post_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.notify_tenant_state_changed_using_post_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def notify_tenant_state_changed_using_post_with_http_info(self, body, **kwargs):  # noqa: E501
        """notifyTenantStateChanged  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.notify_tenant_state_changed_using_post_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: tenantStateChangedRequest (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method notify_tenant_state_changed_using_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `notify_tenant_state_changed_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/billingEndpoint/tenantStateChanged', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def send_account_activated_email_using_post(self, body, **kwargs):  # noqa: E501
        """sendAccountActivatedEmail  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_account_activated_email_using_post(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: sendAccountActivatedEmailRequest (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.send_account_activated_email_using_post_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.send_account_activated_email_using_post_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def send_account_activated_email_using_post_with_http_info(self, body, **kwargs):  # noqa: E501
        """sendAccountActivatedEmail  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_account_activated_email_using_post_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: sendAccountActivatedEmailRequest (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method send_account_activated_email_using_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `send_account_activated_email_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/billingEndpoint/sendAccountActivated', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def send_activation_email_using_post(self, body, **kwargs):  # noqa: E501
        """sendActivationEmail  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_activation_email_using_post(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: sendActivationEmailRequest (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.send_activation_email_using_post_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.send_activation_email_using_post_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def send_activation_email_using_post_with_http_info(self, body, **kwargs):  # noqa: E501
        """sendActivationEmail  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_activation_email_using_post_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: sendActivationEmailRequest (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method send_activation_email_using_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `send_activation_email_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/billingEndpoint/sendActivation', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def send_password_was_reset_email_using_post(self, body, **kwargs):  # noqa: E501
        """sendPasswordWasResetEmail  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_password_was_reset_email_using_post(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: sendPassowordWasResetEmailRequest (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.send_password_was_reset_email_using_post_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.send_password_was_reset_email_using_post_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def send_password_was_reset_email_using_post_with_http_info(self, body, **kwargs):  # noqa: E501
        """sendPasswordWasResetEmail  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_password_was_reset_email_using_post_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: sendPassowordWasResetEmailRequest (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method send_password_was_reset_email_using_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `send_password_was_reset_email_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/billingEndpoint/sendPasswordWasReset', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def send_reset_password_email_using_post(self, body, **kwargs):  # noqa: E501
        """sendResetPasswordEmail  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_reset_password_email_using_post(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: sendResetPasswordEmailRequest (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.send_reset_password_email_using_post_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.send_reset_password_email_using_post_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def send_reset_password_email_using_post_with_http_info(self, body, **kwargs):  # noqa: E501
        """sendResetPasswordEmail  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_reset_password_email_using_post_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: sendResetPasswordEmailRequest (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method send_reset_password_email_using_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `send_reset_password_email_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/billingEndpoint/sendResetPassword', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def tenant_has_billing_read_using_get(self, **kwargs):  # noqa: E501
        """tenantHasBillingRead  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tenant_has_billing_read_using_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.tenant_has_billing_read_using_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.tenant_has_billing_read_using_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def tenant_has_billing_read_using_get_with_http_info(self, **kwargs):  # noqa: E501
        """tenantHasBillingRead  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tenant_has_billing_read_using_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tenant_has_billing_read_using_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/billingEndpoint/tenant/permission/billing/read', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def tenant_has_billing_write_using_get(self, **kwargs):  # noqa: E501
        """tenantHasBillingWrite  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tenant_has_billing_write_using_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.tenant_has_billing_write_using_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.tenant_has_billing_write_using_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def tenant_has_billing_write_using_get_with_http_info(self, **kwargs):  # noqa: E501
        """tenantHasBillingWrite  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tenant_has_billing_write_using_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tenant_has_billing_write_using_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/billingEndpoint/tenant/permission/billing/write', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class DynamicValueBoolean(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'source_type': 'str',
        'source_attribute': 'str',
        'inherit': 'bool'
    }

    attribute_map = {
        'source_type': 'sourceType',
        'source_attribute': 'sourceAttribute',
        'inherit': 'inherit'
    }

    def __init__(self, source_type=None, source_attribute=None, inherit=None):  # noqa: E501
        """DynamicValueBoolean - a model defined in Swagger"""  # noqa: E501
        self._source_type = None
        self._source_attribute = None
        self._inherit = None
        self.discriminator = None
        if source_type is not None:
            self.source_type = source_type
        if source_attribute is not None:
            self.source_attribute = source_attribute
        if inherit is not None:
            self.inherit = inherit

    @property
    def source_type(self):
        """Gets the source_type of this DynamicValueBoolean.  # noqa: E501


        :return: The source_type of this DynamicValueBoolean.  # noqa: E501
        :rtype: str
        """
        return self._source_type

    @source_type.setter
    def source_type(self, source_type):
        """Sets the source_type of this DynamicValueBoolean.


        :param source_type: The source_type of this DynamicValueBoolean.  # noqa: E501
        :type: str
        """
        allowed_values = ["CURRENT_TENANT", "CURRENT_CUSTOMER", "CURRENT_USER", "CURRENT_DEVICE"]  # noqa: E501
        if source_type not in allowed_values:
            raise ValueError(
                "Invalid value for `source_type` ({0}), must be one of {1}"  # noqa: E501
                .format(source_type, allowed_values)
            )

        self._source_type = source_type

    @property
    def source_attribute(self):
        """Gets the source_attribute of this DynamicValueBoolean.  # noqa: E501


        :return: The source_attribute of this DynamicValueBoolean.  # noqa: E501
        :rtype: str
        """
        return self._source_attribute

    @source_attribute.setter
    def source_attribute(self, source_attribute):
        """Sets the source_attribute of this DynamicValueBoolean.


        :param source_attribute: The source_attribute of this DynamicValueBoolean.  # noqa: E501
        :type: str
        """

        self._source_attribute = source_attribute

    @property
    def inherit(self):
        """Gets the inherit of this DynamicValueBoolean.  # noqa: E501


        :return: The inherit of this DynamicValueBoolean.  # noqa: E501
        :rtype: bool
        """
        return self._inherit

    @inherit.setter
    def inherit(self, inherit):
        """Sets the inherit of this DynamicValueBoolean.


        :param inherit: The inherit of this DynamicValueBoolean.  # noqa: E501
        :type: bool
        """

        self._inherit = inherit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DynamicValueBoolean, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DynamicValueBoolean):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class IntegrationInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'IntegrationId',
        'created_time': 'int',
        'tenant_id': 'TenantId',
        'name': 'str',
        'type': 'str',
        'debug_mode': 'bool',
        'enabled': 'bool',
        'allow_create_devices_or_assets': 'bool',
        'version': 'int',
        'status': 'object',
        'stats': 'ArrayNode',
        'edge_template': 'bool',
        'remote': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'created_time': 'createdTime',
        'tenant_id': 'tenantId',
        'name': 'name',
        'type': 'type',
        'debug_mode': 'debugMode',
        'enabled': 'enabled',
        'allow_create_devices_or_assets': 'allowCreateDevicesOrAssets',
        'version': 'version',
        'status': 'status',
        'stats': 'stats',
        'edge_template': 'edgeTemplate',
        'remote': 'remote'
    }

    def __init__(self, id=None, created_time=None, tenant_id=None, name=None, type=None, debug_mode=None, enabled=None, allow_create_devices_or_assets=None, version=None, status=None, stats=None, edge_template=None, remote=None):  # noqa: E501
        """IntegrationInfo - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._created_time = None
        self._tenant_id = None
        self._name = None
        self._type = None
        self._debug_mode = None
        self._enabled = None
        self._allow_create_devices_or_assets = None
        self._version = None
        self._status = None
        self._stats = None
        self._edge_template = None
        self._remote = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if created_time is not None:
            self.created_time = created_time
        if tenant_id is not None:
            self.tenant_id = tenant_id
        self.name = name
        self.type = type
        if debug_mode is not None:
            self.debug_mode = debug_mode
        if enabled is not None:
            self.enabled = enabled
        if allow_create_devices_or_assets is not None:
            self.allow_create_devices_or_assets = allow_create_devices_or_assets
        if version is not None:
            self.version = version
        if status is not None:
            self.status = status
        if stats is not None:
            self.stats = stats
        if edge_template is not None:
            self.edge_template = edge_template
        if remote is not None:
            self.remote = remote

    @property
    def id(self):
        """Gets the id of this IntegrationInfo.  # noqa: E501


        :return: The id of this IntegrationInfo.  # noqa: E501
        :rtype: IntegrationId
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this IntegrationInfo.


        :param id: The id of this IntegrationInfo.  # noqa: E501
        :type: IntegrationId
        """

        self._id = id

    @property
    def created_time(self):
        """Gets the created_time of this IntegrationInfo.  # noqa: E501

        Timestamp of the integration creation, in milliseconds  # noqa: E501

        :return: The created_time of this IntegrationInfo.  # noqa: E501
        :rtype: int
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this IntegrationInfo.

        Timestamp of the integration creation, in milliseconds  # noqa: E501

        :param created_time: The created_time of this IntegrationInfo.  # noqa: E501
        :type: int
        """

        self._created_time = created_time

    @property
    def tenant_id(self):
        """Gets the tenant_id of this IntegrationInfo.  # noqa: E501


        :return: The tenant_id of this IntegrationInfo.  # noqa: E501
        :rtype: TenantId
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this IntegrationInfo.


        :param tenant_id: The tenant_id of this IntegrationInfo.  # noqa: E501
        :type: TenantId
        """

        self._tenant_id = tenant_id

    @property
    def name(self):
        """Gets the name of this IntegrationInfo.  # noqa: E501

        Integration Name  # noqa: E501

        :return: The name of this IntegrationInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this IntegrationInfo.

        Integration Name  # noqa: E501

        :param name: The name of this IntegrationInfo.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def type(self):
        """Gets the type of this IntegrationInfo.  # noqa: E501

        The type of the integration  # noqa: E501

        :return: The type of this IntegrationInfo.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this IntegrationInfo.

        The type of the integration  # noqa: E501

        :param type: The type of this IntegrationInfo.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["OCEANCONNECT", "SIGFOX", "THINGPARK", "TPE", "CHIRPSTACK", "PARTICLE", "TMOBILE_IOT_CDP", "HTTP", "MQTT", "PUB_SUB", "AWS_IOT", "AWS_SQS", "AWS_KINESIS", "IBM_WATSON_IOT", "TTN", "TTI", "AZURE_EVENT_HUB", "OPC_UA", "CUSTOM", "UDP", "TCP", "KAFKA", "AZURE_IOT_HUB", "APACHE_PULSAR", "RABBITMQ", "LORIOT", "COAP", "TUYA", "AZURE_SERVICE_BUS", "KPN"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def debug_mode(self):
        """Gets the debug_mode of this IntegrationInfo.  # noqa: E501

        Boolean flag to enable/disable saving received messages as debug events  # noqa: E501

        :return: The debug_mode of this IntegrationInfo.  # noqa: E501
        :rtype: bool
        """
        return self._debug_mode

    @debug_mode.setter
    def debug_mode(self, debug_mode):
        """Sets the debug_mode of this IntegrationInfo.

        Boolean flag to enable/disable saving received messages as debug events  # noqa: E501

        :param debug_mode: The debug_mode of this IntegrationInfo.  # noqa: E501
        :type: bool
        """

        self._debug_mode = debug_mode

    @property
    def enabled(self):
        """Gets the enabled of this IntegrationInfo.  # noqa: E501

        Boolean flag to enable/disable the integration  # noqa: E501

        :return: The enabled of this IntegrationInfo.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this IntegrationInfo.

        Boolean flag to enable/disable the integration  # noqa: E501

        :param enabled: The enabled of this IntegrationInfo.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def allow_create_devices_or_assets(self):
        """Gets the allow_create_devices_or_assets of this IntegrationInfo.  # noqa: E501

        Boolean flag to allow/disallow the integration to create devices or assets that send message and do not exist in the system yet  # noqa: E501

        :return: The allow_create_devices_or_assets of this IntegrationInfo.  # noqa: E501
        :rtype: bool
        """
        return self._allow_create_devices_or_assets

    @allow_create_devices_or_assets.setter
    def allow_create_devices_or_assets(self, allow_create_devices_or_assets):
        """Sets the allow_create_devices_or_assets of this IntegrationInfo.

        Boolean flag to allow/disallow the integration to create devices or assets that send message and do not exist in the system yet  # noqa: E501

        :param allow_create_devices_or_assets: The allow_create_devices_or_assets of this IntegrationInfo.  # noqa: E501
        :type: bool
        """

        self._allow_create_devices_or_assets = allow_create_devices_or_assets

    @property
    def version(self):
        """Gets the version of this IntegrationInfo.  # noqa: E501


        :return: The version of this IntegrationInfo.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this IntegrationInfo.


        :param version: The version of this IntegrationInfo.  # noqa: E501
        :type: int
        """

        self._version = version

    @property
    def status(self):
        """Gets the status of this IntegrationInfo.  # noqa: E501


        :return: The status of this IntegrationInfo.  # noqa: E501
        :rtype: object
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this IntegrationInfo.


        :param status: The status of this IntegrationInfo.  # noqa: E501
        :type: object
        """

        self._status = status

    @property
    def stats(self):
        """Gets the stats of this IntegrationInfo.  # noqa: E501


        :return: The stats of this IntegrationInfo.  # noqa: E501
        :rtype: ArrayNode
        """
        return self._stats

    @stats.setter
    def stats(self, stats):
        """Sets the stats of this IntegrationInfo.


        :param stats: The stats of this IntegrationInfo.  # noqa: E501
        :type: ArrayNode
        """

        self._stats = stats

    @property
    def edge_template(self):
        """Gets the edge_template of this IntegrationInfo.  # noqa: E501

        Boolean flag that specifies that is regular or edge template integration  # noqa: E501

        :return: The edge_template of this IntegrationInfo.  # noqa: E501
        :rtype: bool
        """
        return self._edge_template

    @edge_template.setter
    def edge_template(self, edge_template):
        """Sets the edge_template of this IntegrationInfo.

        Boolean flag that specifies that is regular or edge template integration  # noqa: E501

        :param edge_template: The edge_template of this IntegrationInfo.  # noqa: E501
        :type: bool
        """

        self._edge_template = edge_template

    @property
    def remote(self):
        """Gets the remote of this IntegrationInfo.  # noqa: E501

        Boolean flag to enable/disable the integration to be executed remotely. Remote integration is launched in a separate microservice. Local integration is executed by the platform core  # noqa: E501

        :return: The remote of this IntegrationInfo.  # noqa: E501
        :rtype: bool
        """
        return self._remote

    @remote.setter
    def remote(self, remote):
        """Sets the remote of this IntegrationInfo.

        Boolean flag to enable/disable the integration to be executed remotely. Remote integration is launched in a separate microservice. Local integration is executed by the platform core  # noqa: E501

        :param remote: The remote of this IntegrationInfo.  # noqa: E501
        :type: bool
        """

        self._remote = remote

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IntegrationInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IntegrationInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from tb_rest_client.api_client import ApiClient


class CustomMenuControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_custom_menu_using_get(self, **kwargs):  # noqa: E501
        """Get end-user Custom Menu configuration (getCustomMenu)  # noqa: E501

        Fetch the Custom Menu object for the end user. The custom menu is configured in the white labeling parameters. If custom menu configuration on the tenant level is present, it overrides the menu configuration of the system level. Similar, if the custom menu configuration on the customer level is present, it overrides the menu configuration of the tenant level.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_custom_menu_using_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: CustomMenu
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_custom_menu_using_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_custom_menu_using_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_custom_menu_using_get_with_http_info(self, **kwargs):  # noqa: E501
        """Get end-user Custom Menu configuration (getCustomMenu)  # noqa: E501

        Fetch the Custom Menu object for the end user. The custom menu is configured in the white labeling parameters. If custom menu configuration on the tenant level is present, it overrides the menu configuration of the system level. Similar, if the custom menu configuration on the customer level is present, it overrides the menu configuration of the tenant level.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_custom_menu_using_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: CustomMenu
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_custom_menu_using_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/customMenu/customMenu', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CustomMenu',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_custom_menu(self, body, **kwargs):  # noqa: E501
        """Create Custom Menu (createCustomMenu)  # noqa: E501

        The api is designed to create Custom Menu without configuration. Is not applicable for update.  Security check is performed to verify that the user has 'WRITE' permission for the custom menu with specified id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_custom_menu(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CustomMenuInfo body: (required)
        :param list[object] assign_to_list: A list of entity ids, separated by comma ','
        :param bool force: Use force if you want to create default menu that conflicts with the existing one (old one will be update NO_ASSIGN assignee type)
        :return: CustomMenu
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_custom_menu_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_custom_menu_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def create_custom_menu_with_http_info(self, body, **kwargs):  # noqa: E501
        """Create Custom Menu (createCustomMenu)  # noqa: E501

        The api is designed to create Custom Menu without configuration. Is not applicable for update.  Security check is performed to verify that the user has 'WRITE' permission for the custom menu with specified id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_custom_menu_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CustomMenuInfo body: (required)
        :param list[object] assign_to_list: A list of entity ids, separated by comma ','
        :param bool force: Use force if you want to create default menu that conflicts with the existing one (old one will be update NO_ASSIGN assignee type)
        :return: CustomMenu
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'assign_to_list', 'force']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_custom_menu" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_custom_menu`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'assign_to_list' in params:
            query_params.append(('assignToList', params['assign_to_list']))  # noqa: E501
            collection_formats['assignToList'] = 'multi'  # noqa: E501
        if 'force' in params:
            query_params.append(('force', params['force']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/customMenu{?assignToList,force}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CustomMenu',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_custom_menu(self, custom_menu_id, **kwargs):  # noqa: E501
        """Delete custom menu (deleteCustomMenu)  # noqa: E501

        Deletes the custom menu based on the provided Custom Menu Id. Referencing non-existing custom menu Id will cause an error. If the custom menu is assigned to the list of users or customers bad request is returned.To delete a custom menu that has assignee list set 'force' request param to true   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_custom_menu(custom_menu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str custom_menu_id: A string value representing the custom menu id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :param bool force: Force set to true will unassign menu before deletion
        :return: CustomMenuDeleteResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_custom_menu_with_http_info(custom_menu_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_custom_menu_with_http_info(custom_menu_id, **kwargs)  # noqa: E501
            return data

    def delete_custom_menu_with_http_info(self, custom_menu_id, **kwargs):  # noqa: E501
        """Delete custom menu (deleteCustomMenu)  # noqa: E501

        Deletes the custom menu based on the provided Custom Menu Id. Referencing non-existing custom menu Id will cause an error. If the custom menu is assigned to the list of users or customers bad request is returned.To delete a custom menu that has assignee list set 'force' request param to true   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_custom_menu_with_http_info(custom_menu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str custom_menu_id: A string value representing the custom menu id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :param bool force: Force set to true will unassign menu before deletion
        :return: CustomMenuDeleteResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['custom_menu_id', 'force']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_custom_menu" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'custom_menu_id' is set
        if ('custom_menu_id' not in params or
                params['custom_menu_id'] is None):
            raise ValueError(
                "Missing the required parameter `custom_menu_id` when calling `delete_custom_menu`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'custom_menu_id' in params:
            path_params['customMenuId'] = params['custom_menu_id']  # noqa: E501

        query_params = []
        if 'force' in params:
            query_params.append(('force', params['force']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/customMenu/{customMenuId}{?force}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CustomMenuDeleteResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_custom_menu_assignee_list(self, custom_menu_id, **kwargs):  # noqa: E501
        """Get Custom Menu assignee list (getCustomMenuAssigneeList)  # noqa: E501

        Fetch the list of Entity Info objects that represents users or customers, or empty list if custom menu is not assigned or has NO_ASSIGN/ALL assignee type.  Security check is performed to verify that the user has 'READ' permission for the custom menu with specified id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_custom_menu_assignee_list(custom_menu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str custom_menu_id: A string value representing the custom menu id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :return: list[EntityInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_custom_menu_assignee_list_with_http_info(custom_menu_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_custom_menu_assignee_list_with_http_info(custom_menu_id, **kwargs)  # noqa: E501
            return data

    def get_custom_menu_assignee_list_with_http_info(self, custom_menu_id, **kwargs):  # noqa: E501
        """Get Custom Menu assignee list (getCustomMenuAssigneeList)  # noqa: E501

        Fetch the list of Entity Info objects that represents users or customers, or empty list if custom menu is not assigned or has NO_ASSIGN/ALL assignee type.  Security check is performed to verify that the user has 'READ' permission for the custom menu with specified id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_custom_menu_assignee_list_with_http_info(custom_menu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str custom_menu_id: A string value representing the custom menu id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :return: list[EntityInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['custom_menu_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_custom_menu_assignee_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'custom_menu_id' is set
        if ('custom_menu_id' not in params or
                params['custom_menu_id'] is None):
            raise ValueError(
                "Missing the required parameter `custom_menu_id` when calling `get_custom_menu_assignee_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'custom_menu_id' in params:
            path_params['customMenuId'] = params['custom_menu_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/customMenu/{customMenuId}/assigneeList', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[EntityInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_custom_menu_config(self, custom_menu_id, **kwargs):  # noqa: E501
        """Get Custom Menu configuration by id (getCustomMenuConfig)  # noqa: E501

        Fetch the Custom Menu configuration based on the provided Custom Menu Id.   Security check is performed to verify that the user has 'READ' permission for the custom menu with specified id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_custom_menu_config(custom_menu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str custom_menu_id: A string value representing the custom menu id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :return: CustomMenuConfig
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_custom_menu_config_with_http_info(custom_menu_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_custom_menu_config_with_http_info(custom_menu_id, **kwargs)  # noqa: E501
            return data

    def get_custom_menu_config_with_http_info(self, custom_menu_id, **kwargs):  # noqa: E501
        """Get Custom Menu configuration by id (getCustomMenuConfig)  # noqa: E501

        Fetch the Custom Menu configuration based on the provided Custom Menu Id.   Security check is performed to verify that the user has 'READ' permission for the custom menu with specified id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_custom_menu_config_with_http_info(custom_menu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str custom_menu_id: A string value representing the custom menu id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :return: CustomMenuConfig
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['custom_menu_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_custom_menu_config" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'custom_menu_id' is set
        if ('custom_menu_id' not in params or
                params['custom_menu_id'] is None):
            raise ValueError(
                "Missing the required parameter `custom_menu_id` when calling `get_custom_menu_config`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'custom_menu_id' in params:
            path_params['customMenuId'] = params['custom_menu_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/customMenu/{customMenuId}/config', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CustomMenuConfig',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_custom_menu_info_by_id(self, custom_menu_id, **kwargs):  # noqa: E501
        """Get Custom Menu Info (getCustomMenuInfoById)  # noqa: E501

        Fetch the Custom Menu Info object based on the provided Custom Menu Id.   Security check is performed to verify that the user has 'READ' permission for the custom menu with specified id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_custom_menu_info_by_id(custom_menu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str custom_menu_id: A string value representing the custom menu id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :return: CustomMenuInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_custom_menu_info_by_id_with_http_info(custom_menu_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_custom_menu_info_by_id_with_http_info(custom_menu_id, **kwargs)  # noqa: E501
            return data

    def get_custom_menu_info_by_id_with_http_info(self, custom_menu_id, **kwargs):  # noqa: E501
        """Get Custom Menu Info (getCustomMenuInfoById)  # noqa: E501

        Fetch the Custom Menu Info object based on the provided Custom Menu Id.   Security check is performed to verify that the user has 'READ' permission for the custom menu with specified id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_custom_menu_info_by_id_with_http_info(custom_menu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str custom_menu_id: A string value representing the custom menu id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :return: CustomMenuInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['custom_menu_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_custom_menu_info_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'custom_menu_id' is set
        if ('custom_menu_id' not in params or
                params['custom_menu_id'] is None):
            raise ValueError(
                "Missing the required parameter `custom_menu_id` when calling `get_custom_menu_info_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'custom_menu_id' in params:
            path_params['customMenuId'] = params['custom_menu_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/customMenu/{customMenuId}/info', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CustomMenuInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_custom_menu_infos(self, page_size, page, **kwargs):  # noqa: E501
        """Get all custom menus configured at user level (getCustomMenuInfos)  # noqa: E501

        Returns a page of custom menu info objects owned by the tenant or the customer of a current user, scope and assigneeType request parameters can be used to filter the result.  Security check is performed to verify that the user has 'READ' permission for the white labeling resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_custom_menu_infos(page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page_size: Maximum amount of entities in a one page (required)
        :param int page: Sequence number of page starting from 0 (required)
        :param str scope: Custom menu scope.
        :param str assignee_type: Custom menu assignee type.
        :param str text_search: The case insensitive 'substring' filter based on the custom menu name.
        :param str sort_property: Property of entity to sort by
        :param str sort_order: Sort order. ASC (ASCENDING) or DESC (DESCENDING)
        :return: PageDataCustomMenuInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_custom_menu_infos_with_http_info(page_size, page, **kwargs)  # noqa: E501
        else:
            (data) = self.get_custom_menu_infos_with_http_info(page_size, page, **kwargs)  # noqa: E501
            return data

    def get_custom_menu_infos_with_http_info(self, page_size, page, **kwargs):  # noqa: E501
        """Get all custom menus configured at user level (getCustomMenuInfos)  # noqa: E501

        Returns a page of custom menu info objects owned by the tenant or the customer of a current user, scope and assigneeType request parameters can be used to filter the result.  Security check is performed to verify that the user has 'READ' permission for the white labeling resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_custom_menu_infos_with_http_info(page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page_size: Maximum amount of entities in a one page (required)
        :param int page: Sequence number of page starting from 0 (required)
        :param str scope: Custom menu scope.
        :param str assignee_type: Custom menu assignee type.
        :param str text_search: The case insensitive 'substring' filter based on the custom menu name.
        :param str sort_property: Property of entity to sort by
        :param str sort_order: Sort order. ASC (ASCENDING) or DESC (DESCENDING)
        :return: PageDataCustomMenuInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_size', 'page', 'scope', 'assignee_type', 'text_search', 'sort_property',
                      'sort_order']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_custom_menu_infos" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'page_size' is set
        if ('page_size' not in params or
                params['page_size'] is None):
            raise ValueError(
                "Missing the required parameter `page_size` when calling `get_custom_menu_infos`")  # noqa: E501
        # verify the required parameter 'page' is set
        if ('page' not in params or
                params['page'] is None):
            raise ValueError("Missing the required parameter `page` when calling `get_custom_menu_infos`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scope' in params:
            query_params.append(('scope', params['scope']))  # noqa: E501
        if 'assignee_type' in params:
            query_params.append(('assigneeType', params['assignee_type']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'text_search' in params:
            query_params.append(('textSearch', params['text_search']))  # noqa: E501
        if 'sort_property' in params:
            query_params.append(('sortProperty', params['sort_property']))  # noqa: E501
        if 'sort_order' in params:
            query_params.append(('sortOrder', params['sort_order']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/customMenu/infos{?scope,assigneeType,pageSize,page,textSearch,sortProperty,sortOrder}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageDataCustomMenuInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_custom_menu_assignee_list(self, id, assignee_type, **kwargs):  # noqa: E501
        """Update custom menu assignee list (updateCustomMenuAssigneeList)  # noqa: E501

        The api designed to update the list of assignees or assignee type based on the provided Custom Menu Id. To change assignee type, put new assignee type in path parameter.  Security check is performed to verify that the user has 'WRITE' permission for the custom menu with specified id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_custom_menu_assignee_list(id, assignee_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str assignee_type: (required)
        :param list[str] body:
        :param bool force: Use force if you want to override default menu
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_custom_menu_assignee_list_with_http_info(id, assignee_type, **kwargs)  # noqa: E501
        else:
            (data) = self.update_custom_menu_assignee_list_with_http_info(id, assignee_type, **kwargs)  # noqa: E501
            return data

    def update_custom_menu_assignee_list_with_http_info(self, id, assignee_type, **kwargs):  # noqa: E501
        """Update custom menu assignee list (updateCustomMenuAssigneeList)  # noqa: E501

        The api designed to update the list of assignees or assignee type based on the provided Custom Menu Id. To change assignee type, put new assignee type in path parameter.  Security check is performed to verify that the user has 'WRITE' permission for the custom menu with specified id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_custom_menu_assignee_list_with_http_info(id, assignee_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str assignee_type: (required)
        :param list[str] body:
        :param bool force: Use force if you want to override default menu
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'assignee_type', 'body', 'force']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_custom_menu_assignee_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError(
                "Missing the required parameter `id` when calling `update_custom_menu_assignee_list`")  # noqa: E501
        # verify the required parameter 'assignee_type' is set
        if ('assignee_type' not in params or
                params['assignee_type'] is None):
            raise ValueError(
                "Missing the required parameter `assignee_type` when calling `update_custom_menu_assignee_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501
        if 'assignee_type' in params:
            path_params['assigneeType'] = params['assignee_type']  # noqa: E501

        query_params = []
        if 'force' in params:
            query_params.append(('force', params['force']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/customMenu/{id}/assign/{assigneeType}{?force}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_custom_menu_config(self, body, custom_menu_id, **kwargs):  # noqa: E501
        """Update Custom Menu configuration based on the provided Custom Menu Id (updateCustomMenuConfig)  # noqa: E501

          Security check is performed to verify that the user has 'WRITE' permission for the custom menu with specified id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_custom_menu_config(body, custom_menu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CustomMenuConfig body: (required)
        :param str custom_menu_id: A string value representing the custom menu id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :return: CustomMenu
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_custom_menu_config_with_http_info(body, custom_menu_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_custom_menu_config_with_http_info(body, custom_menu_id, **kwargs)  # noqa: E501
            return data

    def update_custom_menu_config_with_http_info(self, body, custom_menu_id, **kwargs):  # noqa: E501
        """Update Custom Menu configuration based on the provided Custom Menu Id (updateCustomMenuConfig)  # noqa: E501

          Security check is performed to verify that the user has 'WRITE' permission for the custom menu with specified id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_custom_menu_config_with_http_info(body, custom_menu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CustomMenuConfig body: (required)
        :param str custom_menu_id: A string value representing the custom menu id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :return: CustomMenu
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'custom_menu_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_custom_menu_config" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError(
                "Missing the required parameter `body` when calling `update_custom_menu_config`")  # noqa: E501
        # verify the required parameter 'custom_menu_id' is set
        if ('custom_menu_id' not in params or
                params['custom_menu_id'] is None):
            raise ValueError(
                "Missing the required parameter `custom_menu_id` when calling `update_custom_menu_config`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'custom_menu_id' in params:
            path_params['customMenuId'] = params['custom_menu_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/customMenu/{customMenuId}/config', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CustomMenu',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_custom_menu_name(self, body, custom_menu_id, **kwargs):  # noqa: E501
        """Update Custom Menu name based on the provided Custom Menu Id (updateCustomMenuName)  # noqa: E501

          Security check is performed to verify that the user has 'WRITE' permission for the custom menu with specified id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_custom_menu_name(body, custom_menu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: (required)
        :param str custom_menu_id: A string value representing the custom menu id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_custom_menu_name_with_http_info(body, custom_menu_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_custom_menu_name_with_http_info(body, custom_menu_id, **kwargs)  # noqa: E501
            return data

    def update_custom_menu_name_with_http_info(self, body, custom_menu_id, **kwargs):  # noqa: E501
        """Update Custom Menu name based on the provided Custom Menu Id (updateCustomMenuName)  # noqa: E501

          Security check is performed to verify that the user has 'WRITE' permission for the custom menu with specified id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_custom_menu_name_with_http_info(body, custom_menu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: (required)
        :param str custom_menu_id: A string value representing the custom menu id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'custom_menu_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_custom_menu_name" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError(
                "Missing the required parameter `body` when calling `update_custom_menu_name`")  # noqa: E501
        # verify the required parameter 'custom_menu_id' is set
        if ('custom_menu_id' not in params or
                params['custom_menu_id'] is None):
            raise ValueError(
                "Missing the required parameter `custom_menu_id` when calling `update_custom_menu_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'custom_menu_id' in params:
            path_params['customMenuId'] = params['custom_menu_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/customMenu/{customMenuId}/name', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class Palette(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'colors': 'dict(str, str)',
        'extends': 'str'
    }

    attribute_map = {
        'type': 'type',
        'colors': 'colors',
        'extends': 'extends'
    }

    def __init__(self, type=None, colors=None, extends=None):  # noqa: E501
        """Palette - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._colors = None
        self._extends = None
        self.discriminator = None
        self.type = type
        if colors is not None:
            self.colors = colors
        if extends is not None:
            self.extends = extends

    @property
    def type(self):
        """Gets the type of this Palette.  # noqa: E501

        Name of the pre-defined palette, or 'custom'  # noqa: E501

        :return: The type of this Palette.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Palette.

        Name of the pre-defined palette, or 'custom'  # noqa: E501

        :param type: The type of this Palette.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def colors(self):
        """Gets the colors of this Palette.  # noqa: E501

        Mapping of hue identifier number to the rgb(a) color code  # noqa: E501

        :return: The colors of this Palette.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._colors

    @colors.setter
    def colors(self, colors):
        """Sets the colors of this Palette.

        Mapping of hue identifier number to the rgb(a) color code  # noqa: E501

        :param colors: The colors of this Palette.  # noqa: E501
        :type: dict(str, str)
        """

        self._colors = colors

    @property
    def extends(self):
        """Gets the extends of this Palette.  # noqa: E501

        Pre-defined palette name that the custom palette extends  # noqa: E501

        :return: The extends of this Palette.  # noqa: E501
        :rtype: str
        """
        return self._extends

    @extends.setter
    def extends(self, extends):
        """Sets the extends of this Palette.

        Pre-defined palette name that the custom palette extends  # noqa: E501

        :param extends: The extends of this Palette.  # noqa: E501
        :type: str
        """

        self._extends = extends

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Palette, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Palette):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class MobileAppBundleInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'MobileAppBundleId',
        'created_time': 'int',
        'tenant_id': 'TenantId',
        'title': 'str',
        'description': 'str',
        'android_app_id': 'MobileAppId',
        'ios_app_id': 'MobileAppId',
        'layout_config': 'MobileLayoutConfig',
        'oauth2_enabled': 'bool',
        'android_pkg_name': 'str',
        'ios_pkg_name': 'str',
        'oauth2_client_infos': 'object',
        'qr_code_enabled': 'bool',
        'name': 'str'
    }

    attribute_map = {
        'id': 'id',
        'created_time': 'createdTime',
        'tenant_id': 'tenantId',
        'title': 'title',
        'description': 'description',
        'android_app_id': 'androidAppId',
        'ios_app_id': 'iosAppId',
        'layout_config': 'layoutConfig',
        'oauth2_enabled': 'oauth2Enabled',
        'android_pkg_name': 'androidPkgName',
        'ios_pkg_name': 'iosPkgName',
        'oauth2_client_infos': 'oauth2ClientInfos',
        'qr_code_enabled': 'qrCodeEnabled',
        'name': 'name'
    }

    def __init__(self, id=None, created_time=None, tenant_id=None, title=None, description=None, android_app_id=None, ios_app_id=None, layout_config=None, oauth2_enabled=None, android_pkg_name=None, ios_pkg_name=None, oauth2_client_infos=None, qr_code_enabled=None, name=None):  # noqa: E501
        """MobileAppBundleInfo - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._created_time = None
        self._tenant_id = None
        self._title = None
        self._description = None
        self._android_app_id = None
        self._ios_app_id = None
        self._layout_config = None
        self._oauth2_enabled = None
        self._android_pkg_name = None
        self._ios_pkg_name = None
        self._oauth2_client_infos = None
        self._qr_code_enabled = None
        self._name = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if created_time is not None:
            self.created_time = created_time
        if tenant_id is not None:
            self.tenant_id = tenant_id
        self.title = title
        if description is not None:
            self.description = description
        if android_app_id is not None:
            self.android_app_id = android_app_id
        if ios_app_id is not None:
            self.ios_app_id = ios_app_id
        if layout_config is not None:
            self.layout_config = layout_config
        if oauth2_enabled is not None:
            self.oauth2_enabled = oauth2_enabled
        if android_pkg_name is not None:
            self.android_pkg_name = android_pkg_name
        if ios_pkg_name is not None:
            self.ios_pkg_name = ios_pkg_name
        if oauth2_client_infos is not None:
            self.oauth2_client_infos = oauth2_client_infos
        if qr_code_enabled is not None:
            self.qr_code_enabled = qr_code_enabled
        if name is not None:
            self.name = name

    @property
    def id(self):
        """Gets the id of this MobileAppBundleInfo.  # noqa: E501


        :return: The id of this MobileAppBundleInfo.  # noqa: E501
        :rtype: MobileAppBundleId
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MobileAppBundleInfo.


        :param id: The id of this MobileAppBundleInfo.  # noqa: E501
        :type: MobileAppBundleId
        """

        self._id = id

    @property
    def created_time(self):
        """Gets the created_time of this MobileAppBundleInfo.  # noqa: E501


        :return: The created_time of this MobileAppBundleInfo.  # noqa: E501
        :rtype: object
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this MobileAppBundleInfo.


        :param created_time: The created_time of this MobileAppBundleInfo.  # noqa: E501
        :type: object
        """

        self._created_time = created_time

    @property
    def tenant_id(self):
        """Gets the tenant_id of this MobileAppBundleInfo.  # noqa: E501

        JSON object with Tenant Id  # noqa: E501

        :return: The tenant_id of this MobileAppBundleInfo.  # noqa: E501
        :rtype: TenantId
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this MobileAppBundleInfo.

        JSON object with Tenant Id  # noqa: E501

        :param tenant_id: The tenant_id of this MobileAppBundleInfo.  # noqa: E501
        :type: TenantId
        """

        self._tenant_id = tenant_id

    @property
    def title(self):
        """Gets the title of this MobileAppBundleInfo.  # noqa: E501

        Application bundle title. Cannot be empty  # noqa: E501

        :return: The title of this MobileAppBundleInfo.  # noqa: E501
        :rtype: object
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this MobileAppBundleInfo.

        Application bundle title. Cannot be empty  # noqa: E501

        :param title: The title of this MobileAppBundleInfo.  # noqa: E501
        :type: object
        """
        if title is None:
            raise ValueError("Invalid value for `title`, must not be `None`")  # noqa: E501

        self._title = title

    @property
    def description(self):
        """Gets the description of this MobileAppBundleInfo.  # noqa: E501

        Application bundle description.  # noqa: E501

        :return: The description of this MobileAppBundleInfo.  # noqa: E501
        :rtype: object
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this MobileAppBundleInfo.

        Application bundle description.  # noqa: E501

        :param description: The description of this MobileAppBundleInfo.  # noqa: E501
        :type: object
        """

        self._description = description

    @property
    def android_app_id(self):
        """Gets the android_app_id of this MobileAppBundleInfo.  # noqa: E501

        Android application id  # noqa: E501

        :return: The android_app_id of this MobileAppBundleInfo.  # noqa: E501
        :rtype: MobileAppId
        """
        return self._android_app_id

    @android_app_id.setter
    def android_app_id(self, android_app_id):
        """Sets the android_app_id of this MobileAppBundleInfo.

        Android application id  # noqa: E501

        :param android_app_id: The android_app_id of this MobileAppBundleInfo.  # noqa: E501
        :type: MobileAppId
        """

        self._android_app_id = android_app_id

    @property
    def ios_app_id(self):
        """Gets the ios_app_id of this MobileAppBundleInfo.  # noqa: E501

        IOS application id  # noqa: E501

        :return: The ios_app_id of this MobileAppBundleInfo.  # noqa: E501
        :rtype: MobileAppId
        """
        return self._ios_app_id

    @ios_app_id.setter
    def ios_app_id(self, ios_app_id):
        """Sets the ios_app_id of this MobileAppBundleInfo.

        IOS application id  # noqa: E501

        :param ios_app_id: The ios_app_id of this MobileAppBundleInfo.  # noqa: E501
        :type: MobileAppId
        """

        self._ios_app_id = ios_app_id

    @property
    def layout_config(self):
        """Gets the layout_config of this MobileAppBundleInfo.  # noqa: E501

        Application layout configuration  # noqa: E501

        :return: The layout_config of this MobileAppBundleInfo.  # noqa: E501
        :rtype: MobileLayoutConfig
        """
        return self._layout_config

    @layout_config.setter
    def layout_config(self, layout_config):
        """Sets the layout_config of this MobileAppBundleInfo.

        Application layout configuration  # noqa: E501

        :param layout_config: The layout_config of this MobileAppBundleInfo.  # noqa: E501
        :type: MobileLayoutConfig
        """

        self._layout_config = layout_config

    @property
    def oauth2_enabled(self):
        """Gets the oauth2_enabled of this MobileAppBundleInfo.  # noqa: E501

        Whether OAuth2 settings are enabled or not  # noqa: E501

        :return: The oauth2_enabled of this MobileAppBundleInfo.  # noqa: E501
        :rtype: object
        """
        return self._oauth2_enabled

    @oauth2_enabled.setter
    def oauth2_enabled(self, oauth2_enabled):
        """Sets the oauth2_enabled of this MobileAppBundleInfo.

        Whether OAuth2 settings are enabled or not  # noqa: E501

        :param oauth2_enabled: The oauth2_enabled of this MobileAppBundleInfo.  # noqa: E501
        :type: object
        """

        self._oauth2_enabled = oauth2_enabled

    @property
    def android_pkg_name(self):
        """Gets the android_pkg_name of this MobileAppBundleInfo.  # noqa: E501

        Android package name  # noqa: E501

        :return: The android_pkg_name of this MobileAppBundleInfo.  # noqa: E501
        :rtype: object
        """
        return self._android_pkg_name

    @android_pkg_name.setter
    def android_pkg_name(self, android_pkg_name):
        """Sets the android_pkg_name of this MobileAppBundleInfo.

        Android package name  # noqa: E501

        :param android_pkg_name: The android_pkg_name of this MobileAppBundleInfo.  # noqa: E501
        :type: object
        """

        self._android_pkg_name = android_pkg_name

    @property
    def ios_pkg_name(self):
        """Gets the ios_pkg_name of this MobileAppBundleInfo.  # noqa: E501

        IOS package name  # noqa: E501

        :return: The ios_pkg_name of this MobileAppBundleInfo.  # noqa: E501
        :rtype: object
        """
        return self._ios_pkg_name

    @ios_pkg_name.setter
    def ios_pkg_name(self, ios_pkg_name):
        """Sets the ios_pkg_name of this MobileAppBundleInfo.

        IOS package name  # noqa: E501

        :param ios_pkg_name: The ios_pkg_name of this MobileAppBundleInfo.  # noqa: E501
        :type: object
        """

        self._ios_pkg_name = ios_pkg_name

    @property
    def oauth2_client_infos(self):
        """Gets the oauth2_client_infos of this MobileAppBundleInfo.  # noqa: E501

        List of available oauth2 clients  # noqa: E501

        :return: The oauth2_client_infos of this MobileAppBundleInfo.  # noqa: E501
        :rtype: object
        """
        return self._oauth2_client_infos

    @oauth2_client_infos.setter
    def oauth2_client_infos(self, oauth2_client_infos):
        """Sets the oauth2_client_infos of this MobileAppBundleInfo.

        List of available oauth2 clients  # noqa: E501

        :param oauth2_client_infos: The oauth2_client_infos of this MobileAppBundleInfo.  # noqa: E501
        :type: object
        """

        self._oauth2_client_infos = oauth2_client_infos

    @property
    def qr_code_enabled(self):
        """Gets the qr_code_enabled of this MobileAppBundleInfo.  # noqa: E501

        Indicates if qr code is available for bundle  # noqa: E501

        :return: The qr_code_enabled of this MobileAppBundleInfo.  # noqa: E501
        :rtype: object
        """
        return self._qr_code_enabled

    @qr_code_enabled.setter
    def qr_code_enabled(self, qr_code_enabled):
        """Sets the qr_code_enabled of this MobileAppBundleInfo.

        Indicates if qr code is available for bundle  # noqa: E501

        :param qr_code_enabled: The qr_code_enabled of this MobileAppBundleInfo.  # noqa: E501
        :type: object
        """

        self._qr_code_enabled = qr_code_enabled

    @property
    def name(self):
        """Gets the name of this MobileAppBundleInfo.  # noqa: E501

        Mobile app bundle title  # noqa: E501

        :return: The name of this MobileAppBundleInfo.  # noqa: E501
        :rtype: object
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this MobileAppBundleInfo.

        Mobile app bundle title  # noqa: E501

        :param name: The name of this MobileAppBundleInfo.  # noqa: E501
        :type: object
        """

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MobileAppBundleInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MobileAppBundleInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from tb_rest_client.api_client import ApiClient


class ConverterLibraryControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_downlink_converter(self, integration_type, vendor_name, model, **kwargs):  # noqa: E501
        """Get downlink converter (getDownlinkConverter)  # noqa: E501

        Returns downlink converter body for the vendor, integration type and model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_downlink_converter(integration_type, vendor_name, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str model: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_downlink_converter_with_http_info(integration_type, vendor_name, model, **kwargs)  # noqa: E501
        else:
            (data) = self.get_downlink_converter_with_http_info(integration_type, vendor_name, model, **kwargs)  # noqa: E501
            return data

    def get_downlink_converter_with_http_info(self, integration_type, vendor_name, model, **kwargs):  # noqa: E501
        """Get downlink converter (getDownlinkConverter)  # noqa: E501

        Returns downlink converter body for the vendor, integration type and model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_downlink_converter_with_http_info(integration_type, vendor_name, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str model: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['integration_type', 'vendor_name', 'model']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_downlink_converter" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'integration_type' is set
        if ('integration_type' not in params or
                params['integration_type'] is None):
            raise ValueError("Missing the required parameter `integration_type` when calling `get_downlink_converter`")  # noqa: E501
        # verify the required parameter 'vendor_name' is set
        if ('vendor_name' not in params or
                params['vendor_name'] is None):
            raise ValueError("Missing the required parameter `vendor_name` when calling `get_downlink_converter`")  # noqa: E501
        # verify the required parameter 'model' is set
        if ('model' not in params or
                params['model'] is None):
            raise ValueError("Missing the required parameter `model` when calling `get_downlink_converter`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'integration_type' in params:
            path_params['integrationType'] = params['integration_type']  # noqa: E501
        if 'vendor_name' in params:
            path_params['vendorName'] = params['vendor_name']  # noqa: E501
        if 'model' in params:
            path_params['model'] = params['model']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/converter/library/{integrationType}/{vendorName}/{model}/downlink', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_downlink_converter_metadata(self, integration_type, vendor_name, model, **kwargs):  # noqa: E501
        """Get downlink converter metadata (getDownlinkConverterMetadata)  # noqa: E501

        Returns downlink converter metadata for the vendor, integration type and model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_downlink_converter_metadata(integration_type, vendor_name, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str model: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_downlink_converter_metadata_with_http_info(integration_type, vendor_name, model, **kwargs)  # noqa: E501
        else:
            (data) = self.get_downlink_converter_metadata_with_http_info(integration_type, vendor_name, model, **kwargs)  # noqa: E501
            return data

    def get_downlink_converter_metadata_with_http_info(self, integration_type, vendor_name, model, **kwargs):  # noqa: E501
        """Get downlink converter metadata (getDownlinkConverterMetadata)  # noqa: E501

        Returns downlink converter metadata for the vendor, integration type and model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_downlink_converter_metadata_with_http_info(integration_type, vendor_name, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str model: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['integration_type', 'vendor_name', 'model']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_downlink_converter_metadata" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'integration_type' is set
        if ('integration_type' not in params or
                params['integration_type'] is None):
            raise ValueError("Missing the required parameter `integration_type` when calling `get_downlink_converter_metadata`")  # noqa: E501
        # verify the required parameter 'vendor_name' is set
        if ('vendor_name' not in params or
                params['vendor_name'] is None):
            raise ValueError("Missing the required parameter `vendor_name` when calling `get_downlink_converter_metadata`")  # noqa: E501
        # verify the required parameter 'model' is set
        if ('model' not in params or
                params['model'] is None):
            raise ValueError("Missing the required parameter `model` when calling `get_downlink_converter_metadata`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'integration_type' in params:
            path_params['integrationType'] = params['integration_type']  # noqa: E501
        if 'vendor_name' in params:
            path_params['vendorName'] = params['vendor_name']  # noqa: E501
        if 'model' in params:
            path_params['model'] = params['model']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/converter/library/{integrationType}/{vendorName}/{model}/downlink/metadata', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_downlink_payload(self, integration_type, vendor_name, model, **kwargs):  # noqa: E501
        """Get downlink payload (getDownlinkPayload)  # noqa: E501

        Returns payload example for the downlink converter for the vendor, integration type and model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_downlink_payload(integration_type, vendor_name, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str model: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_downlink_payload_with_http_info(integration_type, vendor_name, model, **kwargs)  # noqa: E501
        else:
            (data) = self.get_downlink_payload_with_http_info(integration_type, vendor_name, model, **kwargs)  # noqa: E501
            return data

    def get_downlink_payload_with_http_info(self, integration_type, vendor_name, model, **kwargs):  # noqa: E501
        """Get downlink payload (getDownlinkPayload)  # noqa: E501

        Returns payload example for the downlink converter for the vendor, integration type and model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_downlink_payload_with_http_info(integration_type, vendor_name, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str model: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['integration_type', 'vendor_name', 'model']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_downlink_payload" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'integration_type' is set
        if ('integration_type' not in params or
                params['integration_type'] is None):
            raise ValueError("Missing the required parameter `integration_type` when calling `get_downlink_payload`")  # noqa: E501
        # verify the required parameter 'vendor_name' is set
        if ('vendor_name' not in params or
                params['vendor_name'] is None):
            raise ValueError("Missing the required parameter `vendor_name` when calling `get_downlink_payload`")  # noqa: E501
        # verify the required parameter 'model' is set
        if ('model' not in params or
                params['model'] is None):
            raise ValueError("Missing the required parameter `model` when calling `get_downlink_payload`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'integration_type' in params:
            path_params['integrationType'] = params['integration_type']  # noqa: E501
        if 'vendor_name' in params:
            path_params['vendorName'] = params['vendor_name']  # noqa: E501
        if 'model' in params:
            path_params['model'] = params['model']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/converter/library/{integrationType}/{vendorName}/{model}/downlink/payload', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_uplink_converter(self, integration_type, vendor_name, model, **kwargs):  # noqa: E501
        """Get uplink converter (getUplinkConverter)  # noqa: E501

        Returns uplink converter body for the vendor, integration type and model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_uplink_converter(integration_type, vendor_name, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str model: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_uplink_converter_with_http_info(integration_type, vendor_name, model, **kwargs)  # noqa: E501
        else:
            (data) = self.get_uplink_converter_with_http_info(integration_type, vendor_name, model, **kwargs)  # noqa: E501
            return data

    def get_uplink_converter_with_http_info(self, integration_type, vendor_name, model, **kwargs):  # noqa: E501
        """Get uplink converter (getUplinkConverter)  # noqa: E501

        Returns uplink converter body for the vendor, integration type and model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_uplink_converter_with_http_info(integration_type, vendor_name, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str model: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['integration_type', 'vendor_name', 'model']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_uplink_converter" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'integration_type' is set
        if ('integration_type' not in params or
                params['integration_type'] is None):
            raise ValueError("Missing the required parameter `integration_type` when calling `get_uplink_converter`")  # noqa: E501
        # verify the required parameter 'vendor_name' is set
        if ('vendor_name' not in params or
                params['vendor_name'] is None):
            raise ValueError("Missing the required parameter `vendor_name` when calling `get_uplink_converter`")  # noqa: E501
        # verify the required parameter 'model' is set
        if ('model' not in params or
                params['model'] is None):
            raise ValueError("Missing the required parameter `model` when calling `get_uplink_converter`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'integration_type' in params:
            path_params['integrationType'] = params['integration_type']  # noqa: E501
        if 'vendor_name' in params:
            path_params['vendorName'] = params['vendor_name']  # noqa: E501
        if 'model' in params:
            path_params['model'] = params['model']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/converter/library/{integrationType}/{vendorName}/{model}/uplink', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_uplink_converter_metadata(self, integration_type, vendor_name, model, **kwargs):  # noqa: E501
        """Get uplink converter metadata (getUplinkConverterMetadata)  # noqa: E501

        Returns uplink converter metadata for the vendor, integration type and model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_uplink_converter_metadata(integration_type, vendor_name, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str model: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_uplink_converter_metadata_with_http_info(integration_type, vendor_name, model, **kwargs)  # noqa: E501
        else:
            (data) = self.get_uplink_converter_metadata_with_http_info(integration_type, vendor_name, model, **kwargs)  # noqa: E501
            return data

    def get_uplink_converter_metadata_with_http_info(self, integration_type, vendor_name, model, **kwargs):  # noqa: E501
        """Get uplink converter metadata (getUplinkConverterMetadata)  # noqa: E501

        Returns uplink converter metadata for the vendor, integration type and model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_uplink_converter_metadata_with_http_info(integration_type, vendor_name, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str model: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['integration_type', 'vendor_name', 'model']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_uplink_converter_metadata" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'integration_type' is set
        if ('integration_type' not in params or
                params['integration_type'] is None):
            raise ValueError("Missing the required parameter `integration_type` when calling `get_uplink_converter_metadata`")  # noqa: E501
        # verify the required parameter 'vendor_name' is set
        if ('vendor_name' not in params or
                params['vendor_name'] is None):
            raise ValueError("Missing the required parameter `vendor_name` when calling `get_uplink_converter_metadata`")  # noqa: E501
        # verify the required parameter 'model' is set
        if ('model' not in params or
                params['model'] is None):
            raise ValueError("Missing the required parameter `model` when calling `get_uplink_converter_metadata`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'integration_type' in params:
            path_params['integrationType'] = params['integration_type']  # noqa: E501
        if 'vendor_name' in params:
            path_params['vendorName'] = params['vendor_name']  # noqa: E501
        if 'model' in params:
            path_params['model'] = params['model']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/converter/library/{integrationType}/{vendorName}/{model}/uplink/metadata', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_uplink_payload(self, integration_type, vendor_name, model, **kwargs):  # noqa: E501
        """Get uplink payload (getUplinkPayload)  # noqa: E501

        Returns payload example for the uplink converter for the vendor, integration type and model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_uplink_payload(integration_type, vendor_name, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str model: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_uplink_payload_with_http_info(integration_type, vendor_name, model, **kwargs)  # noqa: E501
        else:
            (data) = self.get_uplink_payload_with_http_info(integration_type, vendor_name, model, **kwargs)  # noqa: E501
            return data

    def get_uplink_payload_with_http_info(self, integration_type, vendor_name, model, **kwargs):  # noqa: E501
        """Get uplink payload (getUplinkPayload)  # noqa: E501

        Returns payload example for the uplink converter for the vendor, integration type and model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_uplink_payload_with_http_info(integration_type, vendor_name, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str model: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['integration_type', 'vendor_name', 'model']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_uplink_payload" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'integration_type' is set
        if ('integration_type' not in params or
                params['integration_type'] is None):
            raise ValueError("Missing the required parameter `integration_type` when calling `get_uplink_payload`")  # noqa: E501
        # verify the required parameter 'vendor_name' is set
        if ('vendor_name' not in params or
                params['vendor_name'] is None):
            raise ValueError("Missing the required parameter `vendor_name` when calling `get_uplink_payload`")  # noqa: E501
        # verify the required parameter 'model' is set
        if ('model' not in params or
                params['model'] is None):
            raise ValueError("Missing the required parameter `model` when calling `get_uplink_payload`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'integration_type' in params:
            path_params['integrationType'] = params['integration_type']  # noqa: E501
        if 'vendor_name' in params:
            path_params['vendorName'] = params['vendor_name']  # noqa: E501
        if 'model' in params:
            path_params['model'] = params['model']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/converter/library/{integrationType}/{vendorName}/{model}/uplink/payload', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_vendor_models(self, integration_type, vendor_name, **kwargs):  # noqa: E501
        """Get vendor models (getVendorModels)  # noqa: E501

        Returns a list of models for the vendor, integration type and converter type  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_vendor_models(integration_type, vendor_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str converter_type:
        :return: list[Model]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_vendor_models_with_http_info(integration_type, vendor_name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_vendor_models_with_http_info(integration_type, vendor_name, **kwargs)  # noqa: E501
            return data

    def get_vendor_models_with_http_info(self, integration_type, vendor_name, **kwargs):  # noqa: E501
        """Get vendor models (getVendorModels)  # noqa: E501

        Returns a list of models for the vendor, integration type and converter type  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_vendor_models_with_http_info(integration_type, vendor_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str converter_type:
        :return: list[Model]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['integration_type', 'vendor_name', 'converter_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_vendor_models" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'integration_type' is set
        if ('integration_type' not in params or
                params['integration_type'] is None):
            raise ValueError("Missing the required parameter `integration_type` when calling `get_vendor_models`")  # noqa: E501
        # verify the required parameter 'vendor_name' is set
        if ('vendor_name' not in params or
                params['vendor_name'] is None):
            raise ValueError("Missing the required parameter `vendor_name` when calling `get_vendor_models`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'integration_type' in params:
            path_params['integrationType'] = params['integration_type']  # noqa: E501
        if 'vendor_name' in params:
            path_params['vendorName'] = params['vendor_name']  # noqa: E501

        query_params = []
        if 'converter_type' in params:
            query_params.append(('converterType', params['converter_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/converter/library/{integrationType}/{vendorName}/models{?converterType}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Model]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_vendors(self, integration_type, **kwargs):  # noqa: E501
        """Get vendors (getVendors)  # noqa: E501

        Returns a list of vendors for the integration type  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_vendors(integration_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :return: list[Vendor]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_vendors_with_http_info(integration_type, **kwargs)  # noqa: E501
        else:
            (data) = self.get_vendors_with_http_info(integration_type, **kwargs)  # noqa: E501
            return data

    def get_vendors_with_http_info(self, integration_type, **kwargs):  # noqa: E501
        """Get vendors (getVendors)  # noqa: E501

        Returns a list of vendors for the integration type  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_vendors_with_http_info(integration_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :return: list[Vendor]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['integration_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_vendors" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'integration_type' is set
        if ('integration_type' not in params or
                params['integration_type'] is None):
            raise ValueError("Missing the required parameter `integration_type` when calling `get_vendors`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'integration_type' in params:
            path_params['integrationType'] = params['integration_type']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/converter/library/{integrationType}/vendors', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Vendor]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six
from tb_rest_client.models.models_pe.alarm_schedule import AlarmSchedule  # noqa: F401,E501

class SpecificTimeSchedule(AlarmSchedule):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'timezone': 'str',
        'days_of_week': 'list[int]',
        'starts_on': 'int',
        'ends_on': 'int'
    }
    if hasattr(AlarmSchedule, "swagger_types"):
        swagger_types.update(AlarmSchedule.swagger_types)

    attribute_map = {
        'timezone': 'timezone',
        'days_of_week': 'daysOfWeek',
        'starts_on': 'startsOn',
        'ends_on': 'endsOn'
    }
    if hasattr(AlarmSchedule, "attribute_map"):
        attribute_map.update(AlarmSchedule.attribute_map)

    def __init__(self, timezone=None, days_of_week=None, starts_on=None, ends_on=None, *args, **kwargs):  # noqa: E501
        """SpecificTimeSchedule - a model defined in Swagger"""  # noqa: E501
        self._timezone = None
        self._days_of_week = None
        self._starts_on = None
        self._ends_on = None
        self.discriminator = None
        if timezone is not None:
            self.timezone = timezone
        if days_of_week is not None:
            self.days_of_week = days_of_week
        if starts_on is not None:
            self.starts_on = starts_on
        if ends_on is not None:
            self.ends_on = ends_on
        AlarmSchedule.__init__(self, *args, **kwargs)

    @property
    def timezone(self):
        """Gets the timezone of this SpecificTimeSchedule.  # noqa: E501


        :return: The timezone of this SpecificTimeSchedule.  # noqa: E501
        :rtype: str
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """Sets the timezone of this SpecificTimeSchedule.


        :param timezone: The timezone of this SpecificTimeSchedule.  # noqa: E501
        :type: str
        """

        self._timezone = timezone

    @property
    def days_of_week(self):
        """Gets the days_of_week of this SpecificTimeSchedule.  # noqa: E501


        :return: The days_of_week of this SpecificTimeSchedule.  # noqa: E501
        :rtype: list[int]
        """
        return self._days_of_week

    @days_of_week.setter
    def days_of_week(self, days_of_week):
        """Sets the days_of_week of this SpecificTimeSchedule.


        :param days_of_week: The days_of_week of this SpecificTimeSchedule.  # noqa: E501
        :type: list[int]
        """

        self._days_of_week = days_of_week

    @property
    def starts_on(self):
        """Gets the starts_on of this SpecificTimeSchedule.  # noqa: E501


        :return: The starts_on of this SpecificTimeSchedule.  # noqa: E501
        :rtype: int
        """
        return self._starts_on

    @starts_on.setter
    def starts_on(self, starts_on):
        """Sets the starts_on of this SpecificTimeSchedule.


        :param starts_on: The starts_on of this SpecificTimeSchedule.  # noqa: E501
        :type: int
        """

        self._starts_on = starts_on

    @property
    def ends_on(self):
        """Gets the ends_on of this SpecificTimeSchedule.  # noqa: E501


        :return: The ends_on of this SpecificTimeSchedule.  # noqa: E501
        :rtype: int
        """
        return self._ends_on

    @ends_on.setter
    def ends_on(self, ends_on):
        """Sets the ends_on of this SpecificTimeSchedule.


        :param ends_on: The ends_on of this SpecificTimeSchedule.  # noqa: E501
        :type: int
        """

        self._ends_on = ends_on

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SpecificTimeSchedule, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SpecificTimeSchedule):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
